import { world } from "@minecraft/server";

function getScore(target, value, useZero = true) {
    try {
        const objective = world.scoreboard.getObjective(value);
        if (typeof target == "string") return objective.getScore(objective.getParticipants().find((player) => player.displayName == target));
        return objective.getScore(target.scoreboardIdentity);
    } catch {
        return useZero ? 0 : NaN;
    }
}

const killsObjective = world.scoreboard.getObjective("Kills");
const deathsObjective = world.scoreboard.getObjective("Deaths");
const streakObjective = world.scoreboard.getObjective("Streak");

if (!killsObjective) world.scoreboard.addObjective("Kills", "");
if (!deathsObjective) world.scoreboard.addObjective("Deaths", "");
if (!streakObjective) world.scoreboard.addObjective("Streak", "");

world.afterEvents.entityDie.subscribe((data) => {
    let source = data.damageSource.damagingEntity;
    let target = data.deadEntity;

    const streak = getScore(target, "Streak");

    if (source?.typeId === "minecraft:player" && target?.typeId === "minecraft:player") {
        source.runCommand("scoreboard players add @s Kills 1");
        target.runCommand("scoreboard players add @s Deaths 1");

        source.runCommand("scoreboard players add @s Streak 1");

        if (streak > 0) {
            target.runCommand("scoreboard players set @s Streak 0");
            target.sendMessage(`You died with a streak of ${streak}`);
        }

        world.sendMessage(`${target.name} was killed by ${source.name}`);
    }
});